@@ -13,8 +13,8 @@ _STR_LD = string.ascii_letters + string.digits
 
 
 class Constant(object):
-    REQUEST: int = 0
-    RESPONSE: int = 1
+    VERSION: str = "0.5.1"
+    PROGRAMMING_LANGUAGE: str = "Python3"
     SOCKET_RECV_SIZE: int = 1024 ** 1
 
     DECLARE_REQUEST: int = 101
@@ -36,7 +36,7 @@ def _get_event_loop():
 
 
 def gen_id(num: int = 8) -> str:
-    return str(int(time.time() * 1000))[-10:] + ''.join(random.choice(_STR_LD) for i in range(num))
+    return str(int(time.time() * 1000))[-10:] + "".join(random.choice(_STR_LD) for i in range(num))
 
 
 get_event_loop = _get_event_loop()
@@ -46,4 +46,4 @@ def parse_error(exception: Optional[Exception]) -> Optional[Tuple[str, str]]:
     error_response: Optional[Tuple[str, str]] = None
     if exception:
         error_response = (type(exception).__name__, str(exception))
-    return error_response
\ No newline at end of file
+    return error_response
